=== modified file 'bzrlib/plugins/launchpad/__init__.py'
--- bzrlib/plugins/launchpad/__init__.py	2006-05-16 01:30:43 +0000
+++ bzrlib/plugins/launchpad/__init__.py	2006-05-16 02:31:06 +0000
@@ -78,7 +78,7 @@
 
     def run(self, 
             branch_url, 
-            product='', 
+            product='',
             branch_name='',
             branch_title='',
             branch_description='',
@@ -86,8 +86,9 @@
             link_bug=None,
             dry_run=False):
         from lp_registration import (
-            LaunchpadService, BranchRegistrationRequest, BranchBugLinkRequest)
-        rego = BranchRegistrationRequest(branch_url=branch_url, 
+            LaunchpadService, BranchRegistrationRequest, BranchBugLinkRequest,
+            DryRunLaunchpadService)
+        rego = BranchRegistrationRequest(branch_url=branch_url,
                                          branch_name=branch_name,
                                          branch_title=branch_title,
                                          branch_description=branch_description,
@@ -96,12 +97,21 @@
                                          )
         linko = BranchBugLinkRequest(branch_url=branch_url,
                                      bug_id=link_bug)
-        service = LaunchpadService()
+        if not dry_run:
+            service = LaunchpadService()
+            # This gives back the xmlrpc url that can be used for future
+            # operations on the branch.  It's not so useful to print to the
+            # user since they can't do anything with it from a web browser; it
+            # might be nice for the server to tell us about an html url as
+            # well.
+        else:
+            # Run on service entirely in memory
+            service = DryRunLaunchpadService()
         service.gather_user_credentials()
-        if not dry_run:
-            print rego.submit(service)
-            if link_bug:
-                print linko.submit(service)
+        branch_object_url = rego.submit(service)
+        if link_bug:
+            link_bug_url = linko.submit(service)
+        print 'Branch registered.'
 
 register_command(cmd_register_branch)
 

=== modified file 'bzrlib/plugins/launchpad/lp_registration.py'
--- bzrlib/plugins/launchpad/lp_registration.py	2006-05-16 02:08:08 +0000
+++ bzrlib/plugins/launchpad/lp_registration.py	2006-05-16 02:31:06 +0000
@@ -140,6 +140,19 @@
         return service.send_request(self._methodname, self._request_params())
 
 
+class DryRunLaunchpadService(LaunchpadService):
+    """Service that just absorbs requests without sending to server.
+    
+    The dummy service does not need authentication.
+    """
+
+    def send_request(self, method_name, method_params):
+        pass
+
+    def gather_user_credentials(self):
+        pass
+
+
 class BranchRegistrationRequest(BaseRequest):
     """Request to tell Launchpad about a bzr branch."""
 

=== modified file 'bzrlib/plugins/launchpad/test_register.py'
--- bzrlib/plugins/launchpad/test_register.py	2006-05-16 01:30:43 +0000
+++ bzrlib/plugins/launchpad/test_register.py	2006-05-16 02:31:06 +0000
@@ -133,11 +133,11 @@
         """register-branch command requires parameters"""
         self.run_bzr('register-branch', retcode=3)
 
-    def test_21_register_cmd_simple_branch(self):
-        """Register a well-known branch to fake server"""
-        # disabled until we can set a different transport within the command
-        # command
-        ## self.run_bzr('register-branch', self.SAMPLE_URL)
+    def test_register_dry_run(self):
+        out, err = self.run_bzr('register-branch',
+                                'http://test-server.com/bzr/branch',
+                                '--dry-run')
+        self.assertEquals(out, 'Branch registered.\n')
 
     def test_onto_transport(self):
         """Test how the request is sent by transmitting across a mock Transport"""

